==> Data-Format-Pretty-0.01.tar.gz: Data-Format-Pretty-0.01/lib/Data/Format/Pretty.pm <==
package Data::Format::Pretty;

use 5.010;
use strict;
use warnings;

use Module::Load;
use Module::Loaded;

require Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw(format_pretty);

our $VERSION = '0.01'; # VERSION

sub format_pretty {
    my ($data, $opts0) = @_;

    my %opts = $opts0 ? %$opts0 : ();
    my $module = $opts{module};
    if (!$module) {
        if ($ENV{GATEWAY_INTERFACE} || $ENV{PLACK_ENV}) {
            $module = 'HTML';
        } else {
            $module = 'Console';
        }
    }
    delete $opts{module};

    my $module_full = "Data::Format::Pretty::" . $module;
    load $module_full unless is_loaded $module_full;
    my $sub = \&{$module_full . "::format_pretty"};

    $sub->($data, \%opts);
}

1;
# ABSTRACT: Pretty-print data structure


=pod

=head1 NAME

Data::Format::Pretty - Pretty-print data structure

=head1 VERSION

version 0.01

=head1 SYNOPSIS

In your program:

 use Data::Format::Pretty qw(format_pretty);
 print format_pretty($data, 'Console', {interactive=>1});

=head1 DESCRIPTION

Data::Format::Pretty is an extremely simple framework for pretty-printing data
structure. Its focus is on "prettiness" and automatic detection of appropriate
format to use.

To use this framework, install one or more Data::Format::Pretty::* formatter
modules, and call format_pretty($data, $formatter, $opts). Data::Format::Pretty
will delegate formatting to the formatting module, passing $data as well as
format-specific options ($opts).

To develop a formatter, look at one of the formatter module (like
L<Data::Format::Pretty::JSON>) for example. You only need to specify one
function, C<format_pretty>.

=head1 FUNCTIONS

=head2 format_pretty($data, \%opts) => STR

Send $data to formatter module (one of Data::Format::Pretty::* modules) and
return the result. Options:

=over 4

=item * module => STR

Select the formatter module. It will be prefixed with "Data::Format::Pretty::".

Currently if unspecified the default is 'Console', or 'HTML' if CGI/PSGI/plackup
environment is detected. In the future, more sophisticated detection logic will
be used.

=back

The rest of the options will be passed to the formatter module.

=head1 SEE ALSO

One of Data::Format::Pretty::* formatter, like L<Data::Format::Pretty::Console>,
L<Data::Format::Pretty::HTML>, L<Data::Format::Pretty::JSON>,
L<Data::Format::Pretty::YAML>.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

==> Data-Format-Pretty-0.02.tar.gz: Data-Format-Pretty-0.02/lib/Data/Format/Pretty.pm <==
package Data::Format::Pretty;

use 5.010;
use strict;
use warnings;

use Module::Load;
use Module::Loaded;

require Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw(format_pretty);

our $VERSION = '0.02'; # VERSION

sub format_pretty {
    my ($data, $opts0) = @_;

    my %opts = $opts0 ? %$opts0 : ();
    my $module = $opts{module};
    if (!$module) {
        if ($ENV{GATEWAY_INTERFACE} || $ENV{PLACK_ENV}) {
            $module = 'HTML';
        } else {
            $module = 'Console';
        }
    }
    delete $opts{module};

    my $module_full = "Data::Format::Pretty::" . $module;
    load $module_full unless is_loaded $module_full;
    my $sub = \&{$module_full . "::format_pretty"};

    $sub->($data, \%opts);
}

1;
# ABSTRACT: Pretty-print data structure


=pod

=head1 NAME

Data::Format::Pretty - Pretty-print data structure

=head1 VERSION

version 0.02

=head1 SYNOPSIS

In your program:

 use Data::Format::Pretty qw(format_pretty);

 # automatically choose an appropriate formatter
 print format_pretty($data);

 # explicitly select a formatter
 print format_pretty($data, {module=>'JSON'});

 # specify formatter option(s)
 print format_pretty($data, {module=>'Console', interactive=>1});

=head1 DESCRIPTION

Data::Format::Pretty is an extremely simple framework for pretty-printing data
structure. Its focus is on "prettiness" and automatic detection of appropriate
format to use.

To develop a formatter, look at one of the formatter modules (like
L<Data::Format::Pretty::JSON>) for example. You only need to specify one
function, C<format_pretty>.

=head1 FUNCTIONS

=head2 format_pretty($data, \%opts) => STR

Send $data to formatter module (one of Data::Format::Pretty::* modules) and
return the result. Options:

=over 4

=item * module => STR

Select the formatter module. It will be prefixed with "Data::Format::Pretty::".

Currently if unspecified the default is 'Console', or 'HTML' if CGI/PSGI/plackup
environment is detected. In the future, more sophisticated detection logic will
be used.

=back

The rest of the options will be passed to the formatter module.

=head1 SEE ALSO

One of Data::Format::Pretty::* formatter, like L<Data::Format::Pretty::Console>,
L<Data::Format::Pretty::HTML>, L<Data::Format::Pretty::JSON>,
L<Data::Format::Pretty::YAML>.

Alternative data formatting framework/module family: L<Any::Renderer>.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__
